@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::Plugin::CheckChangesHasContent;
 # ABSTRACT: Ensure Changes has content before releasing
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 # Dependencies
 use Dist::Zilla 2.100950 (); # XXX really the next release after this date
@@ -90,7 +90,7 @@ Dist::Zilla::Plugin::CheckChangesHasContent - Ensure Changes has content before
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -172,12 +172,22 @@ Karen Etheridge <ether@cpan.org>
 
 =back
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Randy Stauner
+=for stopwords David Golden Randy Stauner
+
+=over 4
+
+=item *
+
+David Golden <xdg@xdg.me>
+
+=item *
 
 Randy Stauner <randy@magnificent-tears.com>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016 by David Golden.
